<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */

if ( ! function_exists( 'medistore_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since  Medistore Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function medistore_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'medistore_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'medistore_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Medistore Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function medistore_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'medistore_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  Medistore Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function medistore_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'medistore_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'medistore_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  Medistore Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function medistore_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'medistore_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if slider section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[slider_content_type]' )->value();
	return medistore_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[slider_content_type]' )->value();
	return medistore_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[slider_content_type]' )->value();
	return medistore_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if slider separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[slider_content_type]' )->value();
    return medistore_pro_is_slider_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is page.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[about_content_type]' )->value();
	return medistore_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[about_content_type]' )->value();
	return medistore_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_about_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[about_content_type]' )->value();
	return medistore_pro_is_about_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_if_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[about_content_type]' )->value();
	return medistore_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}
/**
 * Check if service section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[service_content_type]' )->value();
	return medistore_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if service section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[service_content_type]' )->value();
	return medistore_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if service section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[service_content_type]' )->value();
	return medistore_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_service_section_hr_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[service_content_type]' )->value();
	return medistore_pro_is_service_section_enable( $control ) && ( 'category' != $content_type);
}

/**
 * Check if testimonial section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_testimonial_section_enable( $control ) {
    return ( $control->manager->get_setting( 'medistore_pro_theme_options[testimonial_section_enable]' )->value() );
}
/**
 * Check if testimonial section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_testimonial_section_content_page_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[testimonial_content_type]' )->value();
    return medistore_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if testimonial section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_testimonial_section_content_post_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[testimonial_content_type]' )->value();
    return medistore_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if testimonial section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_testimonial_section_content_category_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[testimonial_content_type]' )->value();
    return medistore_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[blog_content_type]' )->value();
	return medistore_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[blog_content_type]' )->value();
	return medistore_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[blog_content_type]' )->value();
	return medistore_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[blog_content_type]' )->value();
	return medistore_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if blog separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_blog_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[blog_content_type]' )->value();
    return medistore_pro_is_blog_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if blog appointment section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_blog_section_appointment_enable( $control ) {
    return ( $control->manager->get_setting( 'medistore_pro_theme_options[blog_appointment_date_enable]' )->value() &&  medistore_pro_is_blog_section_enable( $control ) );
}


/**
 * Check if team section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[team_section_enable]' )->value() );
}


/**
 * Check if team section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[team_content_type]' )->value();
	return medistore_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[team_content_type]' )->value();
	return medistore_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[team_content_type]' )->value();
	return medistore_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[team_content_type]' )->value();
	return medistore_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if gallery section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[gallery_content_type]' )->value();
	return medistore_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[gallery_content_type]' )->value();
	return medistore_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[gallery_content_type]' )->value();
	return medistore_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_gallery_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[gallery_content_type]' )->value();
	return medistore_pro_is_gallery_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if gallery separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_gallery_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[gallery_content_type]' )->value();
    return medistore_pro_is_gallery_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if popular_post section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[popular_post_section_enable]' )->value() );
}

/**
 * Check if popular_post section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[popular_post_content_type]' )->value();
	return medistore_pro_is_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_post section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[popular_post_content_type]' )->value();
	return medistore_pro_is_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_post section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[popular_post_content_type]' )->value();
	return medistore_pro_is_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_post section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[popular_post_content_type]' )->value();
	return medistore_pro_is_popular_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if popular_post separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[popular_post_content_type]' )->value();
    return medistore_pro_is_popular_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if featured_post section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[featured_post_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[featured_post_content_type]' )->value();
	return medistore_pro_is_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_post section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_featured_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[featured_post_content_type]' )->value();
	return medistore_pro_is_featured_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[featured_post_content_type]' )->value();
	return medistore_pro_is_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_post separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_featured_post_section_content_seperator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[featured_post_content_type]' )->value();
    return medistore_pro_is_featured_post_section_enable( $control ) && !( 'category' == $content_type ) ;
}

/**
 * Check if recent_post section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[recent_post_section_enable]' )->value() );
}

/**
 * Check if recent_post section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[recent_post_content_type]' )->value();
	return medistore_pro_is_recent_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_post section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[recent_post_content_type]' )->value();
	return medistore_pro_is_recent_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_post section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[recent_post_content_type]' )->value();
	return medistore_pro_is_recent_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent_post section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[recent_post_content_type]' )->value();
	return medistore_pro_is_recent_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if recent_post separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[recent_post_content_type]' )->value();
    return medistore_pro_is_recent_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}


/**
 * Check if subscription section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[subscription_section_enable]' )->value() );
}


/**
 * Check if two_column section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_two_column_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[two_column_section_enable]' )->value() );
}

/**
 * Check if two_column section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_two_column_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[two_column_content_type]' )->value();
	return medistore_pro_is_two_column_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if two_column section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_two_column_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[two_column_content_type]' )->value();
	return medistore_pro_is_two_column_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if two_column section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_two_column_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[two_column_content_type]' )->value();
	return medistore_pro_is_two_column_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if two_column section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_two_column_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[two_column_content_type]' )->value();
	return medistore_pro_is_two_column_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if two_column separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_two_column_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[two_column_content_type]' )->value();
    return medistore_pro_is_two_column_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if featured_products section is enabled.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[featured_products_section_enable]' )->value() );
}

/**
 * Check if featured_products section content type is product.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_featured_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[featured_products_content_type]' )->value();
	return medistore_pro_is_featured_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if featured_products section content type is product-category.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_featured_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[featured_products_content_type]' )->value();
	return medistore_pro_is_featured_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if three_column section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_three_column_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[three_column_section_enable]' )->value() );
}

/**
 * Check if three_column section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_three_column_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[three_column_content_type]' )->value();
	return medistore_pro_is_three_column_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if three_column section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_three_column_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[three_column_content_type]' )->value();
	return medistore_pro_is_three_column_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if three_column section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_three_column_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[three_column_content_type]' )->value();
	return medistore_pro_is_three_column_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if three_column section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_three_column_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[three_column_content_type]' )->value();
	return medistore_pro_is_three_column_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if three_column separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_three_column_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[three_column_content_type]' )->value();
    return medistore_pro_is_three_column_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}
/**
 * Check if most_viewed section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_most_viewed_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[most_viewed_section_enable]' )->value() );
}

/**
 * Check if most_viewed section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_most_viewed_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[most_viewed_content_type]' )->value();
	return medistore_pro_is_most_viewed_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most_viewed section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_most_viewed_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[most_viewed_content_type]' )->value();
	return medistore_pro_is_most_viewed_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_viewed section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_most_viewed_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[most_viewed_content_type]' )->value();
	return medistore_pro_is_most_viewed_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if most_viewed separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_most_viewed_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[most_viewed_content_type]' )->value();
    return medistore_pro_is_most_viewed_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if magazine_featured_post section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[magazine_featured_post_section_enable]' )->value() );
}

/**
 * Check if magazine_featured_post section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_featured_post_content_type]' )->value();
	return medistore_pro_is_magazine_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_featured_post section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_featured_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_featured_post_content_type]' )->value();
	return medistore_pro_is_magazine_featured_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_featured_post section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_featured_post_content_type]' )->value();
	return medistore_pro_is_magazine_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_featured_post section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_featured_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_featured_post_content_type]' )->value();
	return medistore_pro_is_magazine_featured_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if magazine_featured_post separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_featured_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_featured_post_content_type]' )->value();
    return medistore_pro_is_magazine_featured_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if magazine_popular_post section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[magazine_popular_post_section_enable]' )->value() );
}

/**
 * Check if magazine_popular_post section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return medistore_pro_is_magazine_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return medistore_pro_is_magazine_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return medistore_pro_is_magazine_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_popular_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return medistore_pro_is_magazine_popular_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if magazine_popular_post separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_popular_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_popular_post_content_type]' )->value();
    return medistore_pro_is_magazine_popular_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if latest_post section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[latest_post_section_enable]' )->value() );
}

/**
 * Check if latest_post section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[latest_post_content_type]' )->value();
	return medistore_pro_is_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_latest_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[latest_post_content_type]' )->value();
	return medistore_pro_is_latest_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[latest_post_content_type]' )->value();
	return medistore_pro_is_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_post section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_latest_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[latest_post_content_type]' )->value();
	return medistore_pro_is_latest_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if latest_post separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_latest_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[latest_post_content_type]' )->value();
    return medistore_pro_is_latest_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}
/**
 * Check if magazine_latest_post section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[magazine_latest_post_section_enable]' )->value() );
}

/**
 * Check if magazine_latest_post section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_latest_post_content_type]' )->value();
	return medistore_pro_is_magazine_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_latest_post section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_latest_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_latest_post_content_type]' )->value();
	return medistore_pro_is_magazine_latest_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_latest_post section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_latest_post_content_type]' )->value();
	return medistore_pro_is_magazine_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_latest_post section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_latest_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_latest_post_content_type]' )->value();
	return medistore_pro_is_magazine_latest_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if magazine_latest_post separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_latest_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_latest_post_content_type]' )->value();
    return medistore_pro_is_magazine_latest_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}
/**
 * Check if magazine_sport_news section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_sport_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[magazine_sport_news_section_enable]' )->value() );
}

/**
 * Check if magazine_sport_news section content type is post.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_sport_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_sport_news_content_type]' )->value();
	return medistore_pro_is_magazine_sport_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_sport_news section content type is page.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_sport_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_sport_news_content_type]' )->value();
	return medistore_pro_is_magazine_sport_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_sport_news section content type is category.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_sport_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_sport_news_content_type]' )->value();
	return medistore_pro_is_magazine_sport_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_sport_news section content type is recent.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_sport_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_sport_news_content_type]' )->value();
	return medistore_pro_is_magazine_sport_news_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if magazine_sport_news separator section is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_magazine_sport_news_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[magazine_sport_news_content_type]' )->value();
    return medistore_pro_is_magazine_sport_news_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if section is enabled in pro design.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_pro_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'medistore_pro_theme_options[home_layout]' )->value();
	return ( $home_layout == 'pro-design' ||  $home_layout == 'default-design');
}

/**
 * Check if popular_product section is enabled.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[popular_product_section_enable]' )->value() );
}

/**
 * Check if popular_product section content type is category.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_product_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[popular_product_content_type]' )->value();
	return medistore_pro_is_popular_product_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_product section content type is product-category.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[popular_product_content_type]' )->value();
	return medistore_pro_is_popular_product_section_enable( $control ) && ( 'product-category' == $content_type );
}


/**
 * Check if popular_product section separator is enabled.
 *
 * @since  Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_popular_product_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'medistore_pro_theme_options[popular_product_content_type]' )->value();
    return medistore_pro_is_popular_product_section_enable( $control ) && !( 'product-category' == $content_type );
}

/**
 * Check if recent_product section is enabled.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_product_section_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[recent_product_section_enable]' )->value() );
}

/**
 * Check if recent_product section content type is product.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_product_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[recent_product_content_type]' )->value();
	return medistore_pro_is_recent_product_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if recent_product section content type is product-category.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_product_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[recent_product_content_type]' )->value();
	return medistore_pro_is_recent_product_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if recent_product section separator is enable
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_recent_product_section_separator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'medistore_pro_theme_options[recent_product_content_type]' )->value();
	return medistore_pro_is_recent_product_section_enable( $control ) && !( 'product-category' == $content_type );
}

/**
 * Check if section is enabled in second design.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_advertisement_enable( $control ) {
	return ( $control->manager->get_setting( 'medistore_pro_theme_options[enable_advertisement]' )->value() );
}

/**
 * Check if section is enabled in third design.
 *
 * @since Medistore Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function medistore_pro_is_third_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'medistore_pro_theme_options[home_layout]' )->value();
	return (  $home_layout == 'third-design' ||  $home_layout == 'default-design' );
}


function medistore_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'medistore_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}

function medistore_pro_is_pro_layout( $control ) {
	$design = $control->manager->get_setting( 'medistore_pro_theme_options[home_layout]' )->value();
	return ( 'pro-design' == $design );
}


function medistore_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'medistore_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

function medistore_pro_is_third_layout( $control ) {
	$design = $control->manager->get_setting( 'medistore_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $design );
}

function medistore_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'medistore_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}
