<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 * @return array An array of default values
 */

function medistore_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$medistore_pro_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#000',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#d87b4d',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'lite-version',
		'home_layout'						=> 'default-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,
		'search_icon_in_primary_menu_enable'=> (bool) true,
		'enable_cart_button'                => (bool) true,
		'enable_advertisement'              => (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'medistore-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'medistore-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'medistore-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'pro_sortable' 						=> 'slider,featured_products,about,popular_product,service,featured_post,popular_post,recent_product,subscription,latest_post,most_viewed,two_column,magazine_sport_news,three_column,magazine_featured_post,magazine_latest_post,team,testimonial,gallery,blog',

		'default_sortable' 					=> 'slider,featured_products,about,popular_product,team,testimonial,blog',

		'second_sortable' 					=> 'slider,featured_post,popular_post,recent_product,subscription,latest_post',

		'third_sortable' 					=> 'most_viewed,two_column,magazine_sport_news,three_column,magazine_featured_post,magazine_latest_post',

		'fourth_sortable'  					=> 'slider,service,about,recent_product,team,gallery,testimonial,blog,subscription',
		

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'medistore-pro' ),
		'blog_column'						=> 'col-2',


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,
		'hide_author'			   			=> (bool) false,
		'hide_date'			   				=> (bool) false,
		'hide_category'			   			=> (bool) false,

		/* Front Page */

		// Slider
		'slider_section_enable'				=> (bool) true,
		'slider_content_type'				=> 'post',
		'slider_count'						=> 3,
		'slider_autoplay_enable'			=> (bool) false,
		'slider_excerpt_length'				=> 25,
		'slider_btn_txt'                    => esc_html__('Learn More','medistore-pro'),
		'slider_btn_alt_txt'                => esc_html__('Get Started','medistore-pro'),

		// Slider
		'featured_post_section_enable'			=> (bool) true,
		'featured_post_content_type'			=> 'page',
		'featured_post_count'					=> 3,
		
		//popular_post 
		'popular_post_section_enable'		   => (bool) true,
		'popular_post_content_type'			   => 'post',
		'popular_post_sub_title'               => esc_html__('Fashion','medistore-pro'),
		'popular_post_title'    			   => esc_html__('Popular Post','medistore-pro'),
		'popular_post_count'				   => 3,
		'popular_post_column'				   => 'col-3',
		'popular_post_read_more_btn_label'     => esc_html__('Read Full Post','medistore-pro'),
		
		//latest_post 
		'latest_post_section_enable'		   => (bool) true,
		'latest_post_content_type'			   => 'post',
		'latest_post_sub_title'                => esc_html__('Fashion','medistore-pro'),
		'latest_post_title'    				   => esc_html__('Latest Post','medistore-pro'),
		'latest_post_count'					   => 3,
		'latest_post_column'				   => 'col-3',
		'latest_post_read_more_btn_label'      => esc_html__('Continue Reading','medistore-pro'),
		
		//recent_post 
		'recent_post_section_enable'		   => (bool) true,
		'recent_post_content_type'			   => 'post',
		'recent_post_count'				 	   => 3,
		'recent_post_column'				   => 'col-3',
		'recent_post_title'					   => esc_html__( 'From Our Blogs', 'medistore-pro' ),
		'recent_post_sub_title'          	   => esc_html__('Recent Articles','medistore-pro'),
				
		//magazine_featured_post 
		'magazine_featured_post_section_enable'		  => (bool) true,
		'magazine_featured_post_content_type'		  => 'post',
		'magazine_featured_post_section_title'		  => esc_html__( 'Magazine Featured Posts', 'medistore-pro' ),
		'magazine_featured_post_count'				  => 2,
				
		//magazine_latest_post 
		'magazine_latest_post_section_enable'		  => (bool) true,
		'magazine_latest_post_content_type'		 	  => 'post',
		'magazine_latest_post_section_title'		  => esc_html__( 'Latest Posts', 'medistore-pro' ),
		'magazine_latest_post_count'				  => 3,
						
		//magazine_sport_news 
		'magazine_sport_news_section_enable'	   => (bool) true,
		'magazine_sport_news_content_type'		   => 'post',
		'magazine_sport_news_section_title'		   => esc_html__( 'Sports News', 'medistore-pro' ),
		'magazine_sport_news_count'				   => 4,
				
		//popular product
		'popular_product_section_enable'	=> true,
		'popular_product_content_type'		=> 'category',
		'popular_product_count'				=> 6,
		'popular_product_title'				=> esc_html__( 'Browse health products and medicine copy', 'medistore-pro' ),
		'popular_product_btn_title'			=> esc_html__( 'Find More Products', 'medistore-pro' ),

		// recent products
		'recent_product_section_enable'		=> (bool) true,
		'recent_product_count'					=> 4,
		'recent_product_title'					=> esc_html__('Our Products','medistore-pro'),
		'recent_product_sub_title'				=> esc_html__('Discover','medistore-pro'),
		'recent_product_add_to_cart_btn_label'	=> esc_html__('Add To Cart','medistore-pro'),
		'recent_product_content_type'			=> 'product',
				
		// most_viewed
		'most_viewed_section_enable'			=> (bool) true,
		'most_viewed_content_type'				=> 'post',
		'most_viewed_count'						=> 2,
		
		//service
		'service_section_enable'		    => (bool) true,
		'service_content_type'			    =>'post',
		'service_section_sub_title'			=> esc_html__( 'Services', 'medistore-pro' ),
		'service_post_btn_title'			=> esc_html__( 'Read More', 'medistore-pro' ),
		'service_posts_count'			    => 3,
		'service_excerpt_length'			=> 20,
		'service_section_title'			    => esc_html__( 'What We Do', 'medistore-pro' ),
		'service_btn_title'				    => esc_html__( 'View All Services', 'medistore-pro' ),

		//testimonial
        'testimonial_section_enable'        => (bool) true,
		'testimonial_title'	        		=> esc_html__('Hear the inspiring stories of our patients.','medistore-pro'),
		'testimonial_content_type'          => 'post',
		'testimonial_excerpt_length'        => 25,
		'testimonial_posts_count'           => 3,


		// blog
		'blog_section_enable'			    => (bool) true,
		'blog_appointment_date_enable'	    => (bool) true,
		'blog_title'					    => esc_html__( 'Browse health products and medicine copy', 'medistore-pro' ),
		'blog_appointment_day'			    => esc_html__( 'Monday', 'medistore-pro' ),
		'blog_appointment_description'		=> esc_html__( 'Doctors will be available from 8 am : 12 am, kindly call to confirm your appoinment.', 'medistore-pro' ),
		'blog_btn_title'					=> esc_html__( 'Read More Articles', 'medistore-pro' ),
		'blog_content_type'				    => 'recent',
		'blog_count'					    => 3,
		'blog_excerpt_length'			    => 25,
		'blog_column_layout'			    => 'col-3',

		// two_column
		'two_column_section_enable'		    	=> (bool) true,
		'two_column_title'					    => esc_html__( 'Two Column Section', 'medistore-pro' ),
		'two_column_content_type'			    => 'recent',
		'two_column_count'					    => 2,

		// three_column
		'three_column_section_enable'		    => (bool) true,
		'three_column_title'					=> esc_html__( 'Three Column Section', 'medistore-pro' ),
		'three_column_content_type'			    => 'recent',
		'three_column_count'				    => 3,

		// Popular Post
		'gallery_section_enable'		=> (bool) true,
		'gallery_sub_title'         	=> esc_html__('Portfolio','medistore-pro'),
		'gallery_content_type'			=> 'recent',
		'gallery_count'					=> 6,
		'gallery_title'					=> esc_html__( 'Completed Projects', 'medistore-pro' ),
		'gallery_btn_title'				=> esc_html__( 'Show All', 'medistore-pro' ),

		//about 
		'about_section_enable'			    => (bool) true,
		'about_content_type'			    =>'custom',
		'about_custom_title'				=> esc_html__('Sets the standard for high quality care and patient safety!','medistore-pro'),
		'about_excerpt_length'				=> 40,
		'about_custom_content'				=> __('We have 5000+ review and our customers trust on our medicines and quality products.We deliver products in time.You can read more about us. <br> Our adminstration and support staff all have exceptional people skills and trained to assist you.','medistore-pro'),
		'about_btn_txt'                     => esc_html__('Make Appointment','medistore-pro'),
		'about_btn_alt_txt'                 => esc_html__('Find Doctor','medistore-pro'),
		
		// team
		'team_section_enable'			=> true,
		'team_content_type'				=> 'category',
		'team_count'					=> 3,
		'team_column'					=> 'col-3',
		'team_title'					=> esc_html__( 'Meet Our Team', 'medistore-pro' ),
		'team_description'				=> esc_html__( 'Our administration and support staff all have exceptional people skills and trained to assist you with all medical enquires.', 'medistore-pro' ),
		'team_btn_title'				=> esc_html__( 'View All Team', 'medistore-pro' ),
		
		//subscription
		'subscription_section_enable' 		=> true,
		'subscription_section_title'		=>	esc_html__('Subscribe to Our Newsletter', 'medistore-pro'),
		'subscription_section_btn_txt'		=>	esc_html__('Subscribe Now', 'medistore-pro'),
						
		
		// recent products
		'featured_products_section_enable'			=> (bool) true,
		'featured_products_count'					=> 3,
		'featured_products_title'					=> esc_html__('Why we are best in our Town','medistore-pro'),
		'featured_products_description'				=> esc_html__('We have 5000+ review and our customers trust on our medicines and quality products.We deliver products in time.You can read more about us.','medistore-pro'),
		'featured_products_btn_title'				=> esc_html__('Buy Now','medistore-pro'),
		'featured_products_content_type'			=> 'product',
	);

	$output = apply_filters( 'medistore_pro_default_theme_options', $medistore_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}