<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Medistore Pro
 * @since Medistore Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'medistore_pro_about_section',
	array(
		'title'             => esc_html__( 'About us','medistore-pro' ),
		'description'       => esc_html__( 'About us  Section options.', 'medistore-pro' ),
        'panel'             => 'medistore_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
            return (
                medistore_pro_is_pro_layout( $control )
                ||
                medistore_pro_is_default_layout( $control )
                ||
                medistore_pro_is_fourth_layout( $control )
            );
        },
	)
);

// About content enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[about_section_enable]',
	array(
		'default'			=> 	$options['about_section_enable'],
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[about_section_enable]',
		array(
			'label'             => esc_html__( 'About Section Enable', 'medistore-pro' ),
			'section'           => 'medistore_pro_about_section',
			'on_off_label' 		=> medistore_pro_switch_options(),
		)
	)
);

// About content type control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[about_content_type]',
	array(
		'default'          	=> $options['about_content_type'],
		'sanitize_callback' => 'medistore_pro_sanitize_select',
	)
);

// About Excerpt length setting and control.
$wp_customize->add_setting( 'medistore_pro_theme_options[about_excerpt_length]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'default'			=> $options['about_excerpt_length'],
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[about_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'medistore-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in About section', 'medistore-pro' ),
		'section'     		=> 'medistore_pro_about_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'medistore_pro_is_about_section_enable',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[about_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'medistore-pro' ),
		'section'           => 'medistore_pro_about_section',
		'type'				=> 'select',
		'active_callback' 	=> 'medistore_pro_is_about_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'medistore-pro' ),
			'post' 		=> esc_html__( 'Post', 'medistore-pro' ),
			'category' 	=> esc_html__( 'Category', 'medistore-pro' ),
			'custom' 	=> esc_html__( 'Custom', 'medistore-pro' ),
		),
	)
);

	// about pages drop down chooser control and setting
	$wp_customize->add_setting( 'medistore_pro_theme_options[about_content_page]',
		array(
			'sanitize_callback' => 'medistore_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Medistore_Pro_Dropdown_Chooser( $wp_customize,
		'medistore_pro_theme_options[about_content_page]',
			array(
				'label'             => esc_html__( 'Select Page', 'medistore-pro' ),
				'section'           => 'medistore_pro_about_section',
				'choices'			=> medistore_pro_page_choices(),
				'active_callback'	=> 'medistore_pro_is_about_section_content_page_enable',
			)
		)
	);

	// about posts drop down chooser control and setting
	$wp_customize->add_setting( 'medistore_pro_theme_options[about_content_post]',
		array(
			'sanitize_callback' => 'medistore_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Medistore_Pro_Dropdown_Chooser( $wp_customize,
		'medistore_pro_theme_options[about_content_post]',
			array(
				'label'             => esc_html__( 'Select Post', 'medistore-pro' ),
				'section'           => 'medistore_pro_about_section',
				'choices'			=> medistore_pro_post_choices(),
				'active_callback'	=> 'medistore_pro_is_about_section_content_post_enable',
			)
		)
	);


// about posts drop down chooser control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[about_category]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new Medistore_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'medistore_pro_theme_options[about_category]',
		array(
			'label'             => esc_html__( 'Select Categories', 'medistore-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'medistore-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'medistore_pro_about_section',
			'active_callback'	=> 'medistore_pro_is_about_section_content_category_enable',
		)
	)
); 

// About title setting
$wp_customize->add_setting('medistore_pro_theme_options[about_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_custom_title']
    )
);

$wp_customize->add_control('medistore_pro_theme_options[about_custom_title]',
    array(
        'section'			=> 'medistore_pro_about_section',
        'label'				=> esc_html__( 'Title:', 'medistore-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'medistore_pro_if_about_section_content_custom_enable'
    )
);

$wp_customize->selective_refresh->add_partial('medistore_pro_theme_options[about_custom_title]',
    array(
        'selector'            => '#about header.entry-header h2',
        'render_callback'     => 'medistore_pro_about_custom_title_partial',
    )
);

// About content setting
$wp_customize->add_setting('medistore_pro_theme_options[about_custom_content]',
    array(
        'sanitize_callback' => 'medistore_pro_sanitize_html',
        'transport'			=> 'postMessage',
        'default'           => $options['about_custom_content']

    )
);

$wp_customize->add_control('medistore_pro_theme_options[about_custom_content]',
    array(
        'section'			=> 'medistore_pro_about_section',
        'label'				=> esc_html__( 'Content:', 'medistore-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'medistore_pro_if_about_section_content_custom_enable',
		'input_attrs'       => array(
			'rows'=> 4,
			'cols'=> 50
        ),
    )
);

$wp_customize->selective_refresh->add_partial('medistore_pro_theme_options[about_custom_content]',
	array(
		'selector'            => '#about div.entry-content p',
		'render_callback'     => 'medistore_pro_about_custom_content_partial',
	)
);

$wp_customize->add_setting( 'medistore_pro_theme_options[about_custom_image]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_image',
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'medistore_pro_theme_options[about_custom_image]',
		array(
			'label'       		=> esc_html__( 'About Image', 'medistore-pro' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'medistore-pro' ), 550, 521 ),
			'section'     		=> 'medistore_pro_about_section',
			'active_callback'	=> 'medistore_pro_if_about_section_content_custom_enable',
		)
	)
);

//about_btn_txt
$wp_customize->add_setting('medistore_pro_theme_options[about_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_btn_txt'],
    )
);

$wp_customize->add_control('medistore_pro_theme_options[about_btn_txt]',
    array(
        'section'			=> 'medistore_pro_about_section',
        'label'				=> esc_html__( 'Button Text:', 'medistore-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'medistore_pro_is_about_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[about_btn_txt]',
		array(
			'selector'            => '#about div.read-more a:nth-child(1)',
			'settings'            => 'medistore_pro_theme_options[about_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'medistore_pro_about_btn_txt_partial',
		)
	);
}

$wp_customize->add_setting( 'medistore_pro_theme_options[about_btn_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[about_btn_url]',
	array(
		'label'           	=>  esc_html__( 'Button Link ', 'medistore-pro' ),
		'section'        	=> 'medistore_pro_about_section',
		'active_callback' 	=> 'medistore_pro_if_about_section_content_custom_enable',
		'type'				=> 'url',
	)
);


//about_btn_alt_txt
$wp_customize->add_setting('medistore_pro_theme_options[about_btn_alt_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_btn_alt_txt'],
    )
);

$wp_customize->add_control('medistore_pro_theme_options[about_btn_alt_txt]',
    array(
        'section'			=> 'medistore_pro_about_section',
        'label'				=> esc_html__( 'Alt Button Text:', 'medistore-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'medistore_pro_is_about_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[about_btn_alt_txt]',
		array(
			'selector'            => '#about div.read-more a:nth-child(2)',
			'settings'            => 'medistore_pro_theme_options[about_btn_alt_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'medistore_pro_about_btn_alt_txt_partial',
		) 
	);
}

$wp_customize->add_setting( 'medistore_pro_theme_options[about_btn_alt_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[about_btn_alt_url]',
    array(
        'label'           	=> esc_html__( 'Alt Button URL', 'medistore-pro' ),
        'section'        	=> 'medistore_pro_about_section',
        'active_callback' 	=> 'medistore_pro_is_about_section_enable',
        'type'				=> 'url',
    ) 
);


$wp_customize->add_setting( 'medistore_pro_theme_options[about_youtube_video_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[about_youtube_video_url]',
    array(
        'label'           	=> esc_html__( 'Youtube Video URL', 'medistore-pro' ),
        'section'        	=> 'medistore_pro_about_section',
        'active_callback' 	=> 'medistore_pro_is_about_section_enable',
        'type'				=> 'url',
    ) 
);

