<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Medistore Pro
 * @since Medistore Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'medistore_pro_blog_section',
    array(
        'title'             => esc_html__( 'Blog','medistore-pro' ),
        'description'       => esc_html__( 'Blog Section options.', 'medistore-pro' ),
        'panel'             => 'medistore_pro_front_page_panel',
        'active_callback'	=> function( $control ) {
            return (
                medistore_pro_is_pro_layout( $control )
                ||
                medistore_pro_is_default_layout( $control )
                ||
                medistore_pro_is_fourth_layout( $control )
            );
        },
    )
);

// Blog content enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_section_enable]',
    array(
        'default'           =>  $options['blog_section_enable'],
        'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Medistore_Pro_Switch_Control( $wp_customize,
    'medistore_pro_theme_options[blog_section_enable]',
        array(
            'label'             => esc_html__( 'Blog Section Enable', 'medistore-pro' ),
            'section'           => 'medistore_pro_blog_section',
            'on_off_label'      => medistore_pro_switch_options(),
        ) 
    )
);

// blog title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['blog_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'medistore-pro' ),
        'section'           => 'medistore_pro_blog_section',
        'active_callback'   => 'medistore_pro_is_blog_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[blog_title]',
        array(
            'selector'            => '#articles-section .section-header h2.section-title',
            'settings'            => 'medistore_pro_theme_options[blog_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'medistore_pro_blog_title_partial',
        )
    );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_count]',
    array(
        'default'           => $options['blog_count'],
        'sanitize_callback' => 'medistore_pro_sanitize_number_range',
        'validate_callback' => 'medistore_pro_validate_blog_count',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_count]',
    array(
        'label'             => esc_html__( 'Number of Posts', 'medistore-pro' ),
        'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'medistore-pro' ),
        'section'           => 'medistore_pro_blog_section',
        'active_callback'   => 'medistore_pro_is_blog_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 3,
            'max'   => 12,
            'style' => 'width: 100px;'
        ),
    ) 
);

// team content type control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_column_layout]',
	array(
		'default'          	=> $options['blog_column_layout'],
		'sanitize_callback' => 'medistore_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_column_layout]',
	array(
		'label'             => esc_html__( 'Column Layout', 'medistore-pro' ),
		'section'           => 'medistore_pro_blog_section',
		'type'				=> 'select',
		'active_callback' 	=> 'medistore_pro_is_blog_section_enable',
		'choices'			=> array( 
			'col-2'		=> esc_html__( 'Two Column', 'medistore-pro' ),
			'col-3'		=> esc_html__( 'Three Column', 'medistore-pro' ),
			'col-4'		=> esc_html__( 'Four Column', 'medistore-pro' ),
		),
	)
);

// Blog content type control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_content_type]',
    array(
        'default'           => $options['blog_content_type'],
        'sanitize_callback' => 'medistore_pro_sanitize_select',
    ) 
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'medistore-pro' ),
        'section'           => 'medistore_pro_blog_section',
        'type'              => 'select',
        'active_callback'   => 'medistore_pro_is_blog_section_enable',
        'choices'           => array( 
            'page'      => esc_html__( 'Page', 'medistore-pro' ),
            'post'      => esc_html__( 'Post', 'medistore-pro' ),
            'category'  => esc_html__( 'Category', 'medistore-pro' ),
            'recent'    => esc_html__( 'Recent', 'medistore-pro' ),
        ),
    ) 
);

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :

    // blog pages drop down chooser control and setting
    $wp_customize->add_setting( 'medistore_pro_theme_options[blog_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'medistore_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Medistore_Pro_Dropdown_Chooser( $wp_customize, 'medistore_pro_theme_options[blog_content_page_' . $i . ']', 
        array(
            'label'             => sprintf( esc_html__( 'Select Page %d', 'medistore-pro' ), $i ),
            'section'           => 'medistore_pro_blog_section',
            'choices'           => medistore_pro_page_choices(),
            'active_callback'   => 'medistore_pro_is_blog_section_content_page_enable',
        )
    ) );

    // blog posts drop down chooser control and setting
    $wp_customize->add_setting( 'medistore_pro_theme_options[blog_content_post_' . $i . ']', 
        array(
            'sanitize_callback' => 'medistore_pro_sanitize_page',
        ) 
    );

    $wp_customize->add_control( new Medistore_Pro_Dropdown_Chooser( $wp_customize, 'medistore_pro_theme_options[blog_content_post_' . $i . ']', 
        array(
            'label'             => sprintf( esc_html__( 'Select Post %d', 'medistore-pro' ), $i ),
            'section'           => 'medistore_pro_blog_section',
            'choices'           => medistore_pro_post_choices(),
            'active_callback'   => 'medistore_pro_is_blog_section_content_post_enable',
        ) 
    ) );

    //blog separator
    $wp_customize->add_setting('medistore_pro_theme_options[blog_separator'. $i .']',
        array(
            'sanitize_callback'      => 'medistore_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new Medistore_Pro_Customize_Horizontal_Line($wp_customize,'medistore_pro_theme_options[blog_separator'. $i .']',
        array(
            'active_callback'       => 'medistore_pro_is_blog_section_separator_enable',
            'type'                  => 'hr',
            'section'               => 'medistore_pro_blog_section',
        )
    ));

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'medistore_pro_theme_options[blog_content_category]',
    array(
        'sanitize_callback' => 'medistore_pro_sanitize_single_category',
    )
) ;

$wp_customize->add_control( new Medistore_Pro_Dropdown_Taxonomies_Control( $wp_customize,'medistore_pro_theme_options[blog_content_category]',
    array(
        'label'             => esc_html__( 'Select Category', 'medistore-pro' ),
        'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'medistore-pro' ),
        'section'           => 'medistore_pro_blog_section',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'medistore_pro_is_blog_section_content_category_enable'
    ) 
) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_category_exclude]',
    array(
        'sanitize_callback' => 'medistore_pro_sanitize_category_list',
    )
) ;

$wp_customize->add_control( new Medistore_Pro_Dropdown_Multiple_Chooser( $wp_customize,'medistore_pro_theme_options[blog_category_exclude]', 
    array(
        'label'             => esc_html__( 'Select Excluding Categories', 'medistore-pro' ),
        'section'           => 'medistore_pro_blog_section',
        'type'              => 'dropdown_multiple_chooser',
        'choices'           =>  medistore_pro_category_choices(),
        'active_callback'   => 'medistore_pro_is_blog_section_content_recent_enable'
    )
) );


// Blog Excerpt length setting and control.
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_excerpt_length]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'default'			=> $options['blog_excerpt_length'],
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'medistore-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Blog section', 'medistore-pro' ),
		'section'     		=> 'medistore_pro_blog_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'medistore_pro_is_blog_section_enable',
	)
);

// featured product btn title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['blog_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label ', 'medistore-pro' ),
		'section'        	=> 'medistore_pro_blog_section',
		'active_callback' 	=> 'medistore_pro_is_blog_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[blog_btn_title]',
		array(
			'selector'            => '#articles-section div.articles-button div:last-child a',
			'settings'            => 'medistore_pro_theme_options[blog_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'medistore_pro_blog_btn_title_partial',
		)
	);
}

$wp_customize->add_setting( 'medistore_pro_theme_options[blog_btn_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_btn_url]',
    array(
        'label'           	=> esc_html__( 'Button URL', 'medistore-pro' ),
        'section'        	=> 'medistore_pro_blog_section',
        'active_callback' 	=> 'medistore_pro_is_blog_section_enable',
        'type'				=> 'url',
    ) 
);

// Blog content enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_appointment_date_enable]',
    array(
        'default'           =>  $options['blog_appointment_date_enable'],
        'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Medistore_Pro_Switch_Control( $wp_customize,
    'medistore_pro_theme_options[blog_appointment_date_enable]',
        array(
            'label'             => esc_html__( 'Show Appointment Date', 'medistore-pro' ),
            'section'           => 'medistore_pro_blog_section',
            'on_off_label'      => medistore_pro_switch_options(),
        ) 
    )
);

// blog title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_appointment_day]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['blog_appointment_day'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_appointment_day]',
    array(
        'label'             => esc_html__( 'Appointment Title', 'medistore-pro' ),
        'section'           => 'medistore_pro_blog_section',
        'active_callback'   => 'medistore_pro_is_blog_section_appointment_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[blog_appointment_day]',
        array(
            'selector'            => '#articles-section div.articles-button div.read-more a span',
            'settings'            => 'medistore_pro_theme_options[blog_appointment_day]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'medistore_pro_blog_appointment_day_partial',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[blog_appointment_description]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['blog_appointment_description'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[blog_appointment_description]',
    array(
        'label'             => esc_html__( 'Appointment Description', 'medistore-pro' ),
        'section'           => 'medistore_pro_blog_section',
        'active_callback'   => 'medistore_pro_is_blog_section_appointment_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[blog_appointment_description]',
        array(
            'selector'            => '#articles-section div.articles-button div.entry-content p',
            'settings'            => 'medistore_pro_theme_options[blog_appointment_description]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'medistore_pro_blog_appointment_description_partial',
        )
    );
}