<?php
/**
 * Featured Products Section options
 *
 * @package Theme Palace
 * @subpackage Medistore Pro
 * @since Medistore Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add featured_products section
$wp_customize->add_section( 'medistore_pro_featured_products_section',
    array(
        'title'             => esc_html__( 'Featured Product','medistore-pro' ),
        'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'medistore-pro' ),
        'panel'             => 'medistore_pro_front_page_panel',
        'active_callback'	=> function( $control ) {
            return (
                medistore_pro_is_pro_layout( $control )
                ||
                medistore_pro_is_default_layout( $control )
            );
        },
    )
);

// featured_products content enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[featured_products_section_enable]',
    array(
        'default'           =>  $options['featured_products_section_enable'],
        'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Medistore_Pro_Switch_Control( $wp_customize,
    'medistore_pro_theme_options[featured_products_section_enable]',
        array(
            'label'             => esc_html__( 'Featured Product Section Enable', 'medistore-pro' ),
            'section'           => 'medistore_pro_featured_products_section',
            'on_off_label'      => medistore_pro_switch_options(),
        )
    )
);

// featured_products title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[featured_products_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['featured_products_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[featured_products_title]',
    array(
        'label'             => esc_html__( ' Section Title', 'medistore-pro' ),
        'section'           => 'medistore_pro_featured_products_section',
        'active_callback'   => 'medistore_pro_is_featured_products_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[featured_products_title]',
        array(
            'selector'            => '#featured-products header.entry-header h2.entry-title',
            'settings'            => 'medistore_pro_theme_options[featured_products_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'medistore_pro_featured_products_title_partial',
        )
    );
}

// featured_products sub title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[featured_products_description]',
    array(
        'sanitize_callback' => 'wp_kses_post',
        'default'           => $options['featured_products_description'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[featured_products_description]',
    array(
        'label'             => esc_html__( 'Section Description', 'medistore-pro' ),
        'section'           => 'medistore_pro_featured_products_section',
        'active_callback'   => 'medistore_pro_is_featured_products_section_enable',
        'type'              => 'textarea',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[featured_products_description]',
        array(
            'selector'            => '#featured-products div.entry-content p',
            'settings'            => 'medistore_pro_theme_options[featured_products_description]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'medistore_pro_featured_products_description_partial',
        )
    );
}

$wp_customize->add_setting( 'medistore_pro_theme_options[featured_products_count]',
    array(
        'default'           => $options['featured_products_count'],
        'sanitize_callback' => 'medistore_pro_sanitize_number_range',
        'validate_callback' => 'medistore_pro_validate_featured_products_count',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[featured_products_count]',
    array(
        'label'             => esc_html__( 'Number of Product', 'medistore-pro' ),
        'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'medistore-pro' ),
        'section'           => 'medistore_pro_featured_products_section',
        'active_callback'   => 'medistore_pro_is_featured_products_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 1,
            'max'   => 12,
            'style' => 'width: 100px;'
        ),
    )
);

$wp_customize->add_setting( 'medistore_pro_theme_options[featured_products_content_type]',
    array(
        'default'           => $options['featured_products_content_type'],
        'sanitize_callback' => 'medistore_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[featured_products_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'medistore-pro' ),
        'section'           => 'medistore_pro_featured_products_section',
        'type'              => 'select',
        'active_callback'   => 'medistore_pro_is_featured_products_section_enable',
        'choices'           => array(
            'product'           => esc_html__( 'Product', 'medistore-pro' ),
            'product-category'  => esc_html__( 'Product Category', 'medistore-pro' ),
        ),
    )
);

for( $i = 1 ; $i <= $options['featured_products_count'] ; $i++ ){

    $wp_customize->add_setting( 'medistore_pro_theme_options[featured_products_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'medistore_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Medistore_Pro_Dropdown_Chooser( $wp_customize,
        'medistore_pro_theme_options[featured_products_content_page_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Product %d', 'medistore-pro' ), $i ),
                'section'           => 'medistore_pro_featured_products_section',
                'choices'           => medistore_pro_product_choices(),
                'active_callback'   => 'medistore_pro_is_featured_products_section_content_product_enable',
            )
        )
    );
}

$wp_customize->add_setting(  'medistore_pro_theme_options[featured_products_category]',
    array(
        'sanitize_callback' => 'absint',
    )
);

$wp_customize->add_control( new Medistore_Pro_Dropdown_Taxonomies_Control( $wp_customize,
    'medistore_pro_theme_options[featured_products_category]',
        array(
            'label'             => esc_html__( 'Select Product Categories', 'medistore-pro' ),
            'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'medistore-pro' ),
            'section'           => 'medistore_pro_featured_products_section',
            'taxonomy'          => 'product_cat',
            'type'              => 'dropdown-taxonomies',
            'active_callback'   => 'medistore_pro_is_featured_products_section_content_product_category_enable',
        )
    )
);

// featured product btn title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[featured_products_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['featured_products_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[featured_products_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label ', 'medistore-pro' ),
		'section'        	=> 'medistore_pro_featured_products_section',
		'active_callback' 	=> 'medistore_pro_is_featured_products_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[featured_products_btn_title]',
		array(
			'selector'            => '#featured-products div.read-more a',
			'settings'            => 'medistore_pro_theme_options[featured_products_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'medistore_pro_featured_products_btn_title_partial',
		)
	);
}

$wp_customize->add_setting( 'medistore_pro_theme_options[featured_products_btn_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[featured_products_btn_url]',
    array(
        'label'           	=> esc_html__( 'Button URL', 'medistore-pro' ),
        'section'        	=> 'medistore_pro_featured_products_section',
        'active_callback' 	=> 'medistore_pro_is_featured_products_section_enable',
        'type'				=> 'url',
    ) 
);