<?php
/**
 * Most Viewed Section options
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */

// Add Most Viewed section
$wp_customize->add_section( 'medistore_pro_most_viewed_section',
	array(
		'title'             => esc_html__( 'Most Viewed','medistore-pro' ),
		'description'       => esc_html__( 'Most Viewed Section options.', 'medistore-pro' ),
		'panel'             => 'medistore_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
            return (
                medistore_pro_is_pro_layout( $control )
                ||
                medistore_pro_is_third_layout( $control )
            );
        },
	) 
);

// Most Viewed content enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[most_viewed_section_enable]', 
	array(
		'default'			=> 	$options['most_viewed_section_enable'],
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[most_viewed_section_enable]',
		array(
			'label'             => esc_html__( 'Most Viewed Section Enable', 'medistore-pro' ),
			'section'           => 'medistore_pro_most_viewed_section',
			'on_off_label' 		=> medistore_pro_switch_options(),
		)
	)
);

// Most Viewed number control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[most_viewed_count]',
	array(
		'default'          	=> $options['most_viewed_count'],
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'validate_callback' => 'medistore_pro_validate_most_viewed_count',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[most_viewed_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'medistore-pro' ),
		'description'       => esc_html__( 'Note: Min 2 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'medistore-pro' ),
		'section'           => 'medistore_pro_most_viewed_section',
		'active_callback'   => 'medistore_pro_is_most_viewed_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 2,
			'max'	=> 8,
			'style' => 'width: 100px;'
		),
	)
);

// Most Viewed content type control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[most_viewed_content_type]',
	array(
		'default'          	=> $options['most_viewed_content_type'],
		'sanitize_callback' => 'medistore_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[most_viewed_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'medistore-pro' ),
		'section'           => 'medistore_pro_most_viewed_section',
		'type'				=> 'select',
		'active_callback' 	=> 'medistore_pro_is_most_viewed_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'medistore-pro' ),
			'post' 		=> esc_html__( 'Post', 'medistore-pro' ),
			'category' 	=> esc_html__( 'Category', 'medistore-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['most_viewed_count']; $i++ ) :

	// most_viewed pages drop down chooser control and setting
	$wp_customize->add_setting( 'medistore_pro_theme_options[most_viewed_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'medistore_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Medistore_Pro_Dropdown_Chooser( $wp_customize,
		'medistore_pro_theme_options[most_viewed_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'medistore-pro'), $i ),
				'section'           => 'medistore_pro_most_viewed_section',
				'choices'			=> medistore_pro_page_choices(),
				'active_callback'	=> 'medistore_pro_is_most_viewed_section_content_page_enable',
			)
		)
	);

	// most_viewed posts drop down chooser control and setting
	$wp_customize->add_setting( 'medistore_pro_theme_options[most_viewed_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'medistore_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Medistore_Pro_Dropdown_Chooser( $wp_customize,
		'medistore_pro_theme_options[most_viewed_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'medistore-pro'), $i ),
				'section'           => 'medistore_pro_most_viewed_section',
				'choices'			=> medistore_pro_post_choices(),
				'active_callback'	=> 'medistore_pro_is_most_viewed_section_content_post_enable',
			)
		)
	);

	// Medistore_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('medistore_pro_theme_options[most_viewed_separator'. $i .']',
		array(
			'sanitize_callback'      => 'medistore_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Medistore_Pro_Customize_Horizontal_Line($wp_customize,
		'medistore_pro_theme_options[most_viewed_separator'. $i .']',
			array(
				'active_callback'       => 'medistore_pro_is_most_viewed_section_separator_enable',
				'type'                  =>'hr',
				'section'               =>'medistore_pro_most_viewed_section',
			)
		)
	);

endfor;

// most_viewed posts drop down chooser control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[most_viewed_category]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Medistore_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'medistore_pro_theme_options[most_viewed_category]', 
		array(
			'label'             => esc_html__( 'Select Categories', 'medistore-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'medistore-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'medistore_pro_most_viewed_section',
			'active_callback'	=> 'medistore_pro_is_most_viewed_section_content_category_enable',
		)
	)
); 

