<?php
/**
 * Popular Product Section options
 *
 * @package Theme Palace
 * @subpackage Medistore Pro
 * @since Medistore Pro 1.0.0
 */

// Add Product section
$wp_customize->add_section( 'medistore_pro_popular_product_section',
	array(
		'title'             => esc_html__( 'Popular Product','medistore-pro' ),
		'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'medistore-pro' ),
        'panel'       		=> 'medistore_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
			return (
				medistore_pro_is_pro_layout( $control )
				||
				medistore_pro_is_default_layout( $control )
			);
		},
	)
);

// Product content enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[popular_product_section_enable]',
	array(
		'default'			=> 	$options['popular_product_section_enable'],
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[popular_product_section_enable]',
		array(
			'label'             => esc_html__( 'Popular Product Section Enable', 'medistore-pro' ),
			'section'           => 'medistore_pro_popular_product_section',
			'on_off_label' 		=> medistore_pro_switch_options(),
		)
	)
);

// popular_product title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[popular_product_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['popular_product_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[popular_product_title]',
	array(
		'label'           	=> esc_html__( 'Section Title', 'medistore-pro' ),
		'section'        	=> 'medistore_pro_popular_product_section',
		'active_callback' 	=> 'medistore_pro_is_popular_product_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[popular_product_title]',
		array(
			'selector'            => '#product .section-header h2.section-title',
			'settings'            => 'medistore_pro_theme_options[popular_product_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'medistore_pro_popular_product_title_partial',
		)
	);
}

// Product content type control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[popular_product_content_type]',
	array(
		'default'          	=> $options['popular_product_content_type'],
		'sanitize_callback' => 'medistore_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[popular_product_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'medistore-pro' ),
		'section'           => 'medistore_pro_popular_product_section',
		'type'				=> 'select',
		'active_callback' 	=> 'medistore_pro_is_popular_product_section_enable',
		'choices'			=>  medistore_pro_popular_product_content_type()
	)
);

// Event social icons number control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[popular_product_count]',
	array(
		'default'          	=> $options['popular_product_count'],
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'validate_callback' => 'medistore_pro_validate_popular_product_count',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[popular_product_count]',
	array(
		'label'             => esc_html__( 'Number of Product', 'medistore-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'medistore-pro' ),
		'section'           => 'medistore_pro_popular_product_section',
		'active_callback'   => 'medistore_pro_is_popular_product_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 8,
			'style' => 'width: 100px;'
		),
	)
);

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'medistore_pro_theme_options[popular_product_category]',
    array(
        'sanitize_callback' => 'medistore_pro_sanitize_category_list',
    )
);

$wp_customize->add_control( new Medistore_Pro_Dropdown_Multiple_Chooser( $wp_customize,
		'medistore_pro_theme_options[popular_product_category]', 
		array(
			'label'             => esc_html__( 'Select Excluding Categories', 'medistore-pro' ),
			'section'           => 'medistore_pro_popular_product_section',
			'type'              => 'dropdown_multiple_chooser',
			'choices'           =>  medistore_pro_category_choices(),
			'active_callback'   => 'medistore_pro_is_popular_product_section_content_category_enable'
		)
	)
);


// Add dropdown category setting and control.
$wp_customize->add_setting(  'medistore_pro_theme_options[popular_product_content_product_category]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_product_category_list',
	)
);

$wp_customize->add_control( new Medistore_Pro_Dropdown_Multiple_Chooser( $wp_customize,
	'medistore_pro_theme_options[popular_product_content_product_category]',
		array(
			'label'             => esc_html__( 'Select Product Category', 'medistore-pro' ),
			'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'medistore-pro' ),
			'section'           => 'medistore_pro_popular_product_section',
			'choices'           =>  medistore_pro_product_category_choices(),
			'type'              => 'dropdown_multiple_chooser',
			'active_callback'	=> 'medistore_pro_is_popular_product_section_content_product_category_enable'
		)
	)
);


// featured product btn title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[popular_product_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['popular_product_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[popular_product_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label ', 'medistore-pro' ),
		'section'        	=> 'medistore_pro_popular_product_section',
		'active_callback' 	=> 'medistore_pro_is_popular_product_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[popular_product_btn_title]',
		array(
			'selector'            => '#product div.read-more a',
			'settings'            => 'medistore_pro_theme_options[popular_product_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'medistore_pro_popular_product_btn_title_partial',
		)
	);
}

$wp_customize->add_setting( 'medistore_pro_theme_options[popular_product_btn_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[popular_product_btn_url]',
    array(
        'label'           	=> esc_html__( 'Button URL', 'medistore-pro' ),
        'section'        	=> 'medistore_pro_popular_product_section',
        'active_callback' 	=> 'medistore_pro_is_popular_product_section_enable',
        'type'				=> 'url',
    ) 
);