<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'medistore_pro_service_section', 
	array(
		'title'             => esc_html__( 'Services','medistore-pro' ),
		'description'       => esc_html__( 'Services Section options.', 'medistore-pro' ),
		'panel'             => 'medistore_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
            return (
                medistore_pro_is_pro_layout( $control )
                ||
                medistore_pro_is_fourth_layout( $control )
            );
        },
	) 
);

// Service content enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[service_section_enable]', 
	array(
		'default'			=> 	$options['service_section_enable'],
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[service_section_enable]', 
		array(
			'label'             => esc_html__( 'Service Section Enable', 'medistore-pro' ),
			'section'           => 'medistore_pro_service_section',
			'on_off_label' 		=> medistore_pro_switch_options(),
		) 
	)
);


// Service section sub title control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[service_section_sub_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['service_section_sub_title'],
	) 
);

$wp_customize->add_control('medistore_pro_theme_options[service_section_sub_title]', 
	array(
		'label'             => esc_html__( 'Section Sub Title', 'medistore-pro' ),
		'section'           => 'medistore_pro_service_section',
		'type'              =>'text',
		'active_callback'	=> 'medistore_pro_is_service_section_enable',
	)
);

$wp_customize->selective_refresh->add_partial('medistore_pro_theme_options[service_section_sub_title]',
    array(
        'selector'            => '#our-services .section-subtitle',
        'render_callback'     => 'medistore_pro_service_section_partial_sub_title',
    )
);

// Service section title control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[service_section_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['service_section_title'],
		
	) 
);

$wp_customize->add_control('medistore_pro_theme_options[service_section_title]', 
	array(
		'label'             => esc_html__( 'Section Title', 'medistore-pro' ),
		'section'           => 'medistore_pro_service_section',
		'type'              =>'text',
		'active_callback'	=> 'medistore_pro_is_service_section_enable',
	)
);
$wp_customize->selective_refresh->add_partial(
    'medistore_pro_theme_options[service_section_title]',
    array(
        'selector'            => '#our-services .section-title',
        'render_callback'     => 'medistore_pro_service_section_partial_title',
    )
);

// Service content type control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[service_content_type]',
	array(
		'default'          	=> $options['service_content_type'],
		'sanitize_callback' => 'medistore_pro_sanitize_select',
	) 
);

$wp_customize->add_control( 'medistore_pro_theme_options[service_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'medistore-pro' ),
		'section'           => 'medistore_pro_service_section',
		'type'				=> 'select',
		'active_callback' 	=> 'medistore_pro_is_service_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'medistore-pro' ),
			'post' 		=> esc_html__( 'Post', 'medistore-pro' ),
			'category' 	=> esc_html__( 'Category', 'medistore-pro' ),
		),
	) 
);

// Service btn title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[service_post_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['service_post_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[service_post_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label ', 'medistore-pro' ),
		'section'        	=> 'medistore_pro_service_section',
		'active_callback' 	=> 'medistore_pro_is_service_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[service_post_btn_title]',
		array(
			'selector'            => '#our-services div.more-link a',
			'settings'            => 'medistore_pro_theme_options[service_post_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'medistore_pro_service_post_btn_title_partial',
		)
	);
}

// Services post number control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[service_posts_count]', 
	array(
		'default'          	=> $options['service_posts_count'],
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'validate_callback' => 'medistore_pro_validate_service_posts_count',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[service_posts_count]', 
	array(
		'label'             => esc_html__( 'Number of Posts', 'medistore-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'medistore-pro' ),
		'section'           => 'medistore_pro_service_section',
		'active_callback'   => 'medistore_pro_is_service_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
	) 
);

for($i = 1; $i <= $options['service_posts_count']; $i ++):

    // service pages drop down chooser control and setting
	$wp_customize->add_setting( 'medistore_pro_theme_options[service_content_page_'.$i.']',
		array(
			'sanitize_callback' => 'medistore_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  Medistore_Pro_Dropdown_Chooser( $wp_customize,
		'medistore_pro_theme_options[service_content_page_'.$i.']',
			array(
				'label'             => sprintf(esc_html__( 'Select Page : %d', 'medistore-pro'), $i ),
				'section'           => 'medistore_pro_service_section',
				'choices'			=> medistore_pro_page_choices(),
				'active_callback'	=> 'medistore_pro_is_service_section_content_page_enable',
			) 
		)
	);

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'medistore_pro_theme_options[service_content_post_'.$i.']', 
		array(
			'sanitize_callback' => 'medistore_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  Medistore_Pro_Dropdown_Chooser( $wp_customize,
		'medistore_pro_theme_options[service_content_post_'.$i.']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'medistore-pro'), $i ),
				'section'           => 'medistore_pro_service_section',
				'choices'			=> medistore_pro_post_choices(),
				'active_callback'	=> 'medistore_pro_is_service_section_content_post_enable',
			)
		)
	);

    // Medistore_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('medistore_pro_theme_options[service_separator'. $i .']',
		array(
			'sanitize_callback'      => 'medistore_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new  Medistore_Pro_Customize_Horizontal_Line($wp_customize,
		'medistore_pro_theme_options[service_separator'. $i .']',
			array(
				'active_callback'       => 'medistore_pro_is_service_section_hr_enable',
				'type'                  =>'hr',
				'section'               =>'medistore_pro_service_section',
			)
		)
	);

endfor;

// service category drop down chooser control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[service_category]', 
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Medistore_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'medistore_pro_theme_options[service_category]',
		array(
			'label'             => esc_html__( 'Select Categories', 'medistore-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'medistore-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'medistore_pro_service_section',
			'active_callback'	=> 'medistore_pro_is_service_section_content_category_enable',
		) 
	)
);

// Service Excerpt length setting and control.
$wp_customize->add_setting( 'medistore_pro_theme_options[service_excerpt_length]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'default'			=> $options['service_excerpt_length'],
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[service_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'medistore-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Service section', 'medistore-pro' ),
		'section'     		=> 'medistore_pro_service_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'medistore_pro_is_service_section_enable',
	)
);

// Service btn title setting and control
$wp_customize->add_setting( 'medistore_pro_theme_options[service_btn_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'           => $options['service_btn_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[service_btn_title]',
	array(
		'label'           	=> esc_html__( 'Button Label ', 'medistore-pro' ),
		'section'        	=> 'medistore_pro_service_section',
		'active_callback' 	=> 'medistore_pro_is_service_section_enable',
		'type'				=> 'text',
	)
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[service_btn_title]',
		array(
			'selector'            => '#our-services div.read-more a',
			'settings'            => 'medistore_pro_theme_options[service_btn_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'medistore_pro_service_btn_title_partial',
		)
	);
}

$wp_customize->add_setting( 'medistore_pro_theme_options[service_btn_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[service_btn_url]',
    array(
        'label'           	=> esc_html__( 'Button URL', 'medistore-pro' ),
        'section'        	=> 'medistore_pro_service_section',
        'active_callback' 	=> 'medistore_pro_is_service_section_enable',
        'type'				=> 'url',
    ) 
);