<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'medistore_pro_slider_section',
	array(
		'title'             => esc_html__( 'Slider','medistore-pro' ),
		'description'       => esc_html__( 'Slider Section options.', 'medistore-pro' ),
		'panel'             => 'medistore_pro_front_page_panel',
		'active_callback'	=> function( $control ) {
			return (
				medistore_pro_is_pro_layout( $control )
				||
				medistore_pro_is_default_layout( $control )
				||
				medistore_pro_is_second_layout( $control )
				||
				medistore_pro_is_fourth_layout( $control )
			);
		},
	)
);

// Slider content enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[slider_section_enable]', 
	array(
		'default'			=> 	$options['slider_section_enable'],
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[slider_section_enable]',
		array(
			'label'             => esc_html__( 'Slider Section Enable', 'medistore-pro' ),
			'section'           => 'medistore_pro_slider_section',
			'on_off_label' 		=> medistore_pro_switch_options(),
		)
	)
);

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[slider_autoplay_enable]',
	array(
		'default'			=> 	$options['slider_autoplay_enable'],
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[slider_autoplay_enable]',
		array(
			'label'             => esc_html__( 'Slider Autoplay Enable', 'medistore-pro' ),
			'section'           => 'medistore_pro_slider_section',
			'active_callback'   => 'medistore_pro_is_slider_section_enable',
			'on_off_label' 		=> medistore_pro_switch_options(),
		)
	)
);

// Slider number control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[slider_count]',
	array(
		'default'          	=> $options['slider_count'],
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'validate_callback' => 'medistore_pro_validate_slider_count',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[slider_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'medistore-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'medistore-pro' ),
		'section'           => 'medistore_pro_slider_section',
		'active_callback'   => 'medistore_pro_is_slider_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 5,
			'style' => 'width: 100px;'
		),
	)
);

// Slider Excerpt length setting and control.
$wp_customize->add_setting( 'medistore_pro_theme_options[slider_excerpt_length]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'default'			=> $options['slider_excerpt_length'],
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[slider_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'medistore-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Slider section', 'medistore-pro' ),
		'section'     		=> 'medistore_pro_slider_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'medistore_pro_is_slider_section_enable',
	)
);


// Slider content type control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[slider_content_type]',
	array(
		'default'          	=> $options['slider_content_type'],
		'sanitize_callback' => 'medistore_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[slider_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'medistore-pro' ),
		'section'           => 'medistore_pro_slider_section',
		'type'				=> 'select',
		'active_callback' 	=> 'medistore_pro_is_slider_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'medistore-pro' ),
			'post' 		=> esc_html__( 'Post', 'medistore-pro' ),
			'category' 	=> esc_html__( 'Category', 'medistore-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['slider_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'medistore_pro_theme_options[slider_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'medistore_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Medistore_Pro_Dropdown_Chooser( $wp_customize,
		'medistore_pro_theme_options[slider_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'medistore-pro'), $i ),
				'section'           => 'medistore_pro_slider_section',
				'choices'			=> medistore_pro_page_choices(),
				'active_callback'	=> 'medistore_pro_is_slider_section_content_page_enable',
			)
		)
	);

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'medistore_pro_theme_options[slider_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'medistore_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Medistore_Pro_Dropdown_Chooser( $wp_customize,
		'medistore_pro_theme_options[slider_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'medistore-pro'), $i ),
				'section'           => 'medistore_pro_slider_section',
				'choices'			=> medistore_pro_post_choices(),
				'active_callback'	=> 'medistore_pro_is_slider_section_content_post_enable',
			)
		)
	);

	// Medistore_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('medistore_pro_theme_options[slider_separator'. $i .']',
		array(
			'sanitize_callback'      => 'medistore_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Medistore_Pro_Customize_Horizontal_Line($wp_customize,
		'medistore_pro_theme_options[slider_separator'. $i .']',
			array(
				'active_callback'       => 'medistore_pro_is_slider_section_separator_enable',
				'type'                  =>'hr',
				'section'               =>'medistore_pro_slider_section',
			)
		)
	);

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'medistore_pro_theme_options[slider_category]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Medistore_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'medistore_pro_theme_options[slider_category]', 
		array(
			'label'             => esc_html__( 'Select Categories', 'medistore-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'medistore-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'medistore_pro_slider_section',
			'active_callback'	=> 'medistore_pro_is_slider_section_content_category_enable',
		)
	)
); 

//slider_btn_txt
$wp_customize->add_setting('medistore_pro_theme_options[slider_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['slider_btn_txt'],
    )
);

$wp_customize->add_control('medistore_pro_theme_options[slider_btn_txt]',
    array(
        'section'			=> 'medistore_pro_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'medistore-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'medistore_pro_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[slider_btn_txt]',
		array(
			'selector'            => '#featured-slider article div.read-more a:nth-child(1)',
			'settings'            => 'medistore_pro_theme_options[slider_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'medistore_pro_slider_btn_txt_partial',
		) 
	);
}

//slider_btn_alt_txt
$wp_customize->add_setting('medistore_pro_theme_options[slider_btn_alt_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['slider_btn_alt_txt'],
    )
);

$wp_customize->add_control('medistore_pro_theme_options[slider_btn_alt_txt]',
    array(
        'section'			=> 'medistore_pro_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'medistore-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'medistore_pro_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[slider_btn_alt_txt]',
		array(
			'selector'            => '#featured-slider div.read-more a:nth-child(2)',
			'settings'            => 'medistore_pro_theme_options[slider_btn_alt_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'medistore_pro_slider_btn_alt_txt_partial',
		) 
	);
}

$wp_customize->add_setting( 'medistore_pro_theme_options[slider_btn_alt_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[slider_btn_alt_url]',
    array(
        'label'           	=> esc_html__( 'Button Alt URL', 'medistore-pro' ),
        'section'        	=> 'medistore_pro_slider_section',
        'active_callback' 	=> 'medistore_pro_is_slider_section_enable',
        'type'				=> 'url',
    ) 
);
