<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Medistore Pro
 * @since Medistore Pro 1.0.0
 */

// Subscription section
$wp_customize->add_section('medistore_pro_subscription_section',
    array(
        'title'         => esc_html__( 'Subscription', 'medistore-pro' ),
        'description'   => sprintf( esc_html__( '%1$sJetpack%2$s should be active and site should be connected to WordPress.com for this section to work.', 'medistore-pro' ), '<a target="_blank" href="https://wordpress.org/plugins/jetpack">', '</a>' ),
        'panel'         => 'medistore_pro_front_page_panel',
        'active_callback'	=> function( $control ) {
			return (
				medistore_pro_is_pro_layout( $control )
				||
				medistore_pro_is_second_layout( $control )
				||
				medistore_pro_is_fourth_layout( $control )
			);
		},
    )
);

// Subscription enable setting
$wp_customize->add_setting('medistore_pro_theme_options[subscription_section_enable]',
    array(
        'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
        'default'           => $options['subscription_section_enable'],
    )
);

$wp_customize->add_control(new Medistore_Pro_Switch_Control($wp_customize,
    'medistore_pro_theme_options[subscription_section_enable]',
        array(
            'section'		=> 'medistore_pro_subscription_section',
            'label'			=> esc_html__( 'Enable subscription.', 'medistore-pro' ),
            'on_off_label'  => medistore_pro_switch_options(),
        )
    )
);

// Subscription Background image setting
$wp_customize->add_setting('medistore_pro_theme_options[subscription_bg_image]',
    array(
        'sanitize_callback' => 'medistore_pro_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
    'medistore_pro_theme_options[subscription_bg_image]',
        array(
            'section'			=> 'medistore_pro_subscription_section',
            'label'				=> esc_html__( 'Background Image:', 'medistore-pro' ),
            'active_callback' 	=> 'medistore_pro_is_subscription_section_enable',
        )
    )
);

// Subscribe title setting
$wp_customize->add_setting('medistore_pro_theme_options[subscription_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('medistore_pro_theme_options[subscription_section_title]',
    array(
        'section'		    => 'medistore_pro_subscription_section',
        'label'			    => esc_html__( 'Section Title:', 'medistore-pro' ),
        'active_callback'   => 'medistore_pro_is_subscription_section_enable',
        'type'              =>'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[subscription_section_title]',
		array(
			'selector'            => '#subscribe-us div.subscribe-form-wrapper h2.widgettitle',
			'settings'            => 'medistore_pro_theme_options[subscription_section_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'medistore_pro_subscription_section_title_partial',
		) 
	);
}

// Subscribe button text setting
$wp_customize->add_setting('medistore_pro_theme_options[subscription_section_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_btn_txt'],
    )
);

$wp_customize->add_control('medistore_pro_theme_options[subscription_section_btn_txt]',
    array(
        'section'		    => 'medistore_pro_subscription_section',
        'label'			    => esc_html__( 'Button text:', 'medistore-pro' ),
        'active_callback'   => 'medistore_pro_is_subscription_section_enable'
    )
);
    
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'medistore_pro_theme_options[subscription_section_btn_txt]',
        array(
            'selector'            => '#subscribe-us div.subscribe-form-wrapper #subscribe-submit button',
            'settings'            => 'medistore_pro_theme_options[subscription_section_btn_txt]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'medistore_pro_subscription_section_btn_txt_partial',
        ) 
    );
}