<?php

/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section('medistore_pro_testimonial_section',
    array(
        'title'         => esc_html__('Testimonials', 'medistore-pro'),
        'description'   => esc_html__('Testimonials Section options.', 'medistore-pro'),
        'panel'         => 'medistore_pro_front_page_panel',
        'active_callback'	=> function( $control ) {
            return (
                medistore_pro_is_pro_layout( $control )
                ||
                medistore_pro_is_default_layout( $control )
                ||
                medistore_pro_is_fourth_layout( $control )
            );
        },

    )
);

// Testimonial content enable control and setting
$wp_customize->add_setting('medistore_pro_theme_options[testimonial_section_enable]',
    array(
        'default'           => $options['testimonial_section_enable'],
        'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control(new  Medistore_Pro_Switch_Control($wp_customize,
    'medistore_pro_theme_options[testimonial_section_enable]',
        array(
            'label'         => esc_html__('Testimonial Section Enable', 'medistore-pro'),
            'section'       => 'medistore_pro_testimonial_section',
            'on_off_label'  => medistore_pro_switch_options(),
        )
    )
);

// Testimonial section title control and setting
$wp_customize->add_setting('medistore_pro_theme_options[testimonial_title]',
    array(
        'default'               => $options['testimonial_title'],
        'sanitize_callback'     => 'sanitize_text_field',
        'transport'             => 'postMessage'
    )
);

$wp_customize->add_control('medistore_pro_theme_options[testimonial_title]',
    array(
        'label'                 => esc_html__('Testimonial Title', 'medistore-pro'),
        'section'               => 'medistore_pro_testimonial_section',
        'type'                  => 'text',
        'active_callback'       => 'medistore_pro_is_testimonial_section_enable',
    )
);

$wp_customize->selective_refresh->add_partial('medistore_pro_theme_options[testimonial_title]',
    array(
        'selector'          => '#testimonials div.section-header > p',
        'render_callback'   => 'medistore_pro_testimonial_section_partial_title',
    )
);


// Testimonial Excerpt length setting and control.
$wp_customize->add_setting( 'medistore_pro_theme_options[testimonial_excerpt_length]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_number_range',
		'default'			=> $options['testimonial_excerpt_length'],
	)
);

$wp_customize->add_control( 'medistore_pro_theme_options[testimonial_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'medistore-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Testimonial section', 'medistore-pro' ),
		'section'     		=> 'medistore_pro_testimonial_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'medistore_pro_is_testimonial_section_enable',
	)
);

//Testimonial section content control type setting and control
$wp_customize->add_setting('medistore_pro_theme_options[testimonial_content_type]',
    array(
        'default'               => $options['testimonial_content_type'],
        'sanitize_callback'     => 'medistore_pro_sanitize_select',
    )
);

$wp_customize->add_control('medistore_pro_theme_options[testimonial_content_type]',
    array(
        'label'                 => esc_html__('Content Type', 'medistore-pro'),
        'section'               => 'medistore_pro_testimonial_section',
        'type'                  => 'select',
        'active_callback'       => 'medistore_pro_is_testimonial_section_enable',
        'choices'               => array(
            'page'      => esc_html__('Page', 'medistore-pro'),
            'post'      => esc_html__('Post', 'medistore-pro'),
            'category'  => esc_html__('Category', 'medistore-pro'),
        ),
    )
);


// Testimonial post number control and setting
$wp_customize->add_setting('medistore_pro_theme_options[testimonial_posts_count]',
    array(
        'default'               => $options['testimonial_posts_count'],
        'sanitize_callback'     => 'medistore_pro_sanitize_number_range',
		'validate_callback'     => 'medistore_pro_validate_testimonial_count',
    )
);

$wp_customize->add_control('medistore_pro_theme_options[testimonial_posts_count]',
    array(
        'label'                 => esc_html__('Number of Posts', 'medistore-pro'),
		'description'           => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'medistore-pro' ),
        'section'               => 'medistore_pro_testimonial_section',
        'active_callback'       => 'medistore_pro_is_testimonial_section_enable',
        'type'                  => 'number',
        'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
    )
);

for ($i = 1; $i <= $options['testimonial_posts_count']; $i++):

    // Testimonial pages drop down chooser control and setting
    $wp_customize->add_setting('medistore_pro_theme_options[testimonial_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'medistore_pro_sanitize_page',
        )
    );

    $wp_customize->add_control(new  Medistore_Pro_Dropdown_Chooser($wp_customize,
        'medistore_pro_theme_options[testimonial_content_page_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Page : %d', 'medistore-pro'), $i),
                'section'           => 'medistore_pro_testimonial_section',
                'choices'           => medistore_pro_page_choices(),
                'active_callback'   => 'medistore_pro_is_testimonial_section_content_page_enable',
            )
        )
    );

    // Testimonial posts drop down chooser control and setting
    $wp_customize->add_setting('medistore_pro_theme_options[testimonial_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'medistore_pro_sanitize_page',
        )
    );

    $wp_customize->add_control(new  Medistore_Pro_Dropdown_Chooser($wp_customize,
        'medistore_pro_theme_options[testimonial_content_post_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Post : %d', 'medistore-pro'), $i),
                'section'           => 'medistore_pro_testimonial_section',
                'choices'           => medistore_pro_post_choices(),
                'active_callback'   => 'medistore_pro_is_testimonial_section_content_post_enable',
            )
        )
    );

    // Testimonial posts sub title control and setting
    $wp_customize->add_setting('medistore_pro_theme_options[testimonial_post_designation_' . $i . ']',
        array(
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control(new  Medistore_Pro_Dropdown_Chooser($wp_customize,
        'medistore_pro_theme_options[testimonial_post_designation_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Designation : %d', 'medistore-pro'), $i),
                'section'           => 'medistore_pro_testimonial_section',
                'active_callback'   => 'medistore_pro_is_testimonial_section_enable',
                'type'              => 'text',
            )
        )
    );

    //testimonial separator
    $wp_customize->add_setting('medistore_pro_theme_options[testimonial_separator'. $i .']',
        array(
            'sanitize_callback'      => 'medistore_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new  Medistore_Pro_Customize_Horizontal_Line($wp_customize,
        'medistore_pro_theme_options[testimonial_separator'. $i .']',
            array(
                'active_callback'       => 'medistore_pro_is_testimonial_section_enable',
                'type'                  =>'hr',
                'section'               =>'medistore_pro_testimonial_section',
            )
        )
    );

endfor;

// Testimonial category drop down chooser control and setting
$wp_customize->add_setting('medistore_pro_theme_options[testimonial_category]',
    array(
        'sanitize_callback' => 'medistore_pro_sanitize_single_category',
    )
);

$wp_customize->add_control(new  Medistore_Pro_Dropdown_Taxonomies_Control($wp_customize,
    'medistore_pro_theme_options[testimonial_category]',
            array(
                'label'             => esc_html__('Select Categories', 'medistore-pro'),
                'description'       => esc_html__('Note: Latest selected no of posts will be shown from selected category', 'medistore-pro'),
                'type'              => 'dropdown-taxonomies',
                'section'           => 'medistore_pro_testimonial_section',
                'active_callback'   => 'medistore_pro_is_testimonial_section_content_category_enable',
            )
        )
    );

