<?php
/**
 * Menu options
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */

// Add sidebar section
$wp_customize->add_section( 'medistore_pro_menu',
	array(
		'title'             => esc_html__('Header Menu','medistore-pro'),
		'description'       => esc_html__( 'Header Menu options.', 'medistore-pro' ),
		'panel'             => 'nav_menus',
	)
);

// Menu sticky setting and control.
$wp_customize->add_setting( 'medistore_pro_theme_options[menu_sticky]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
		'default'           => $options['menu_sticky'],
	)
);

$wp_customize->add_control( new  Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[menu_sticky]',
		array(
			'label'             => esc_html__( 'Make Menu Sticky', 'medistore-pro' ),
			'section'           => 'medistore_pro_menu',
			'on_off_label' 		=> medistore_pro_switch_options(),
		)
	)
);

$wp_customize->add_setting( 'medistore_pro_theme_options[search_icon_in_primary_menu_enable]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
		'default'           => $options['search_icon_in_primary_menu_enable'],
	)
);

$wp_customize->add_control( new  Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[search_icon_in_primary_menu_enable]',
		array(
			'label'             => esc_html__( 'Show Search Icon', 'medistore-pro' ),
			'description'       => esc_html__( 'Show Search Icon in Primary menu', 'medistore-pro' ),
			'section'           => 'medistore_pro_menu',
			'on_off_label' 		=> medistore_pro_switch_options(),
		)
	)
);

$wp_customize->add_setting( 'medistore_pro_theme_options[enable_cart_button]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
		'default'           => $options['enable_cart_button'],
	)
);

$wp_customize->add_control( new  Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[enable_cart_button]',
		array(
			'label'             => esc_html__( 'Show Cart Button', 'medistore-pro' ),
			'section'           => 'medistore_pro_menu',
			'on_off_label' 		=> medistore_pro_switch_options(),
			'active_callback'	=> function( $control ) {
				return (
					class_exists( 'WooCommerce' )
				);
			},
		)
	)
);


$wp_customize->add_setting( 'medistore_pro_theme_options[enable_advertisement]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_switch_control',
		'default'           => $options['enable_advertisement'],
	)
);

$wp_customize->add_control( new  Medistore_Pro_Switch_Control( $wp_customize,
	'medistore_pro_theme_options[enable_advertisement]',
		array(
			'label'             => esc_html__( 'Enable Advertisement', 'medistore-pro' ),
			'section'           => 'medistore_pro_menu',
			'on_off_label' 		=> medistore_pro_switch_options(),
			'active_callback'	=> 'medistore_pro_is_third_layout'
		)
	)
);

$wp_customize->add_setting( 'medistore_pro_theme_options[advertisement_image]',
	array(
		'sanitize_callback' => 'medistore_pro_sanitize_image',
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'medistore_pro_theme_options[advertisement_image]',
		array(
			'label'       		=> esc_html__( 'Advertisement Image', 'medistore-pro' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'medistore-pro' ), 1350, 385 ),
			'section'     		=> 'medistore_pro_menu',
			'active_callback'	=> function( $control ) {
				return (
					medistore_pro_is_third_layout( $control )
					&&
					medistore_pro_is_advertisement_enable( $control )
				);
			},
		) 
	)
);

$wp_customize->add_setting( 'medistore_pro_theme_options[advertisement_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'medistore_pro_theme_options[advertisement_url]',
    array(
        'label'           	=> esc_html__( 'Advertisement URL', 'medistore-pro' ),
        'section'        	=> 'medistore_pro_menu',
        'type'				=> 'url',
		'active_callback'	=> function( $control ) {
			return (
				medistore_pro_is_third_layout( $control )
				&&
				medistore_pro_is_advertisement_enable( $control )
			);
		},
    ) 
);
