<?php
/**
 * Features section
 *
 * This is the template for the content of featured_post section
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */
if ( ! function_exists( 'medistore_pro_add_featured_post_section' ) ) :
    /**
    * Add featured_post section
    *
    *@since  Medistore Pro 1.0.0
    */
    function medistore_pro_add_featured_post_section() {
    	$options = medistore_pro_get_theme_options();
        // Check if featured_post is enabled on frontpage
        $featured_post_enable = apply_filters( 'medistore_pro_section_status', true, 'featured_post_section_enable' );

        if ( true !== $featured_post_enable ) {
            return false;
        }
        // Get featured_post section details
        $section_details = array();
        $section_details = apply_filters( 'medistore_pro_filter_featured_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_post section now.
        medistore_pro_render_featured_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'medistore_pro_get_featured_post_section_details' ) ) :
    /**
    * featured_post section details.
    *
    * @since  Medistore Pro 1.0.0
    * @param array $input featured_post section details.
    */
    function medistore_pro_get_featured_post_section_details( $input ) {
        $options = medistore_pro_get_theme_options();

        // Content type.
        $featured_post_content_type  = $options['featured_post_content_type'];
        $featured_post_count = ! empty( $options['featured_post_count'] ) ? $options['featured_post_count'] : 3;
        
        $content = array();
        switch ( $featured_post_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_post_count; $i++ ) {
                    if ( ! empty( $options['featured_post_content_page_' . $i] ) ) :
                        $page_ids[] = $options['featured_post_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_post_count; $i++ ) {
                    if ( ! empty( $options['featured_post_content_post_' . $i] ) ) :
                        $post_ids[] = $options['featured_post_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_post_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_post_content_category'] ) ? $options['featured_post_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_post_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 0;
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_post section content details.
add_filter( 'medistore_pro_filter_featured_post_section_details', 'medistore_pro_get_featured_post_section_details' );


if ( ! function_exists( 'medistore_pro_render_featured_post_section' ) ) :
  /**
   * Start featured_post section
   *
   * @return string featured_post content
   * @since  Medistore Pro 1.0.0
   *
   */
   function medistore_pro_render_featured_post_section( $content_details = array() ) {
        $options = medistore_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <div id="blog-featured-posts" class="relative page-section same-background">
                <div class="wrapper"> 
                    <div class="blog-section-content col-3 clear">
                        <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="blog-featured-item" style="background-image: url('<?php echo esc_url( $content['image'] )?>');">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>
                            </div><!-- .blog-featured-item -->
                        </article>

                        <?php endforeach; ?>
                    </div><!-- .blog-section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php 
    }
endif;