<?php
/**
 * featured_products section
 *
 * This is the template for the content of featured_products section
 *
 * @package Theme Palace
 * @subpackage Medistore Pro
 * @since Medistore Pro 1.0.0
 */
if ( ! function_exists( 'medistore_pro_add_featured_products_section' ) ) :
    /**
    * Add featured_products section
    *
    *@since Medistore Pro 1.0.0
    */
    function medistore_pro_add_featured_products_section() {
        $options = medistore_pro_get_theme_options();
        // Check if featured_products is enabled on frontpage
        $featured_products_enable = apply_filters( 'medistore_pro_section_status', true, 'featured_products_section_enable' );

        if ( ( true !== $featured_products_enable ) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }

        // Get featured_products section details
        $section_details = array();
        $section_details = apply_filters( 'medistore_pro_filter_featured_products_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_products section now.
        medistore_pro_render_featured_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'medistore_pro_get_featured_products_section_details' ) ) :
    /**
    * featured_products section details.
    *
    * @since Medistore Pro 1.0.0
    * @param array $input featured_products section details.
    */
    function medistore_pro_get_featured_products_section_details( $input ) {
        $options = medistore_pro_get_theme_options();

        // Content type.
        $featured_products_content_type  = $options['featured_products_content_type'];     
        $featured_products_count = ! empty( $options['featured_products_count'] ) ? $options['featured_products_count'] : 3;
        
        $content = array();
        $content = array();
        switch ( $featured_products_content_type ) {

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_products_count; $i++ ) {
                    if ( ! empty( $options['featured_products_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_products_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_products_count ),
                    'orderby'           => 'post__in',
                );

            break;
            case 'product-category':
                $cat_id = ! empty( $options['featured_products_category'] ) ? $options['featured_products_category'] : '';

                $args = array(
                    'post_type'         => 'product',
                    'posts_per_page'    => absint( $featured_products_count ),
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'product_cat',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );

            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = medistore_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_products section content details.
add_filter( 'medistore_pro_filter_featured_products_section_details', 'medistore_pro_get_featured_products_section_details' );


if ( ! function_exists( 'medistore_pro_render_featured_products_section' ) ) :
  /**
   * Start featured_products section
   *
   * @return string featured_products content
   * @since Medistore Pro 1.0.0
   *
   */
   function medistore_pro_render_featured_products_section( $content_details = array() ) {
        $options = medistore_pro_get_theme_options();
        $featured_products_btn_url = (!empty($options['featured_products_btn_url'])) ? $options['featured_products_btn_url'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="featured-products" class="relative page-section">
                <div class="wrapper">
                    <div class="section-content">
                        <header class="entry-header">
                            <h2 class="entry-title"><?php echo esc_html( $options['featured_products_title'] ); ?></h2>
                        </header>

                        <div class="entry-content">
                            <p><?php echo wp_kses_post( $options['featured_products_description'] ); ?></p>
                        </div><!-- .entry-content-->

                        <?php if(!empty($options['featured_products_btn_title']) && !empty($featured_products_btn_url)) : ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url($featured_products_btn_url); ?>" class="btn"><?php echo esc_html( $options['featured_products_btn_title'] ); ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                    </div>  
                    <ul class="products col-3">
                        <?php foreach ( $content_details as $content ):  $product = new WC_Product( $content['id'] ); ?>

                        <li class="product featured-products">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                <img src="<?php echo esc_url($content['image']); ?>">
                                <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </a>
                            <div class="product_meta"><a href="<?php echo esc_url($content['url']); ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                <?php 
                                    $terms = get_the_terms ( $content['id'], 'product_cat' );

                                    foreach ( $terms as $term ) { ?>
                                        <span class="posted_in">
                                            <a href="<?php echo esc_url( get_term_link( $term->term_id, 'product_cat' ) ) ?>"><?php echo esc_html( $term->name) ; ?></a>
                                        </span><!-- .posted_in -->
                                    <?php } ?>
                                <span class="price">
                                    <?php  echo $product->get_price_html(); ?> 
                                </span>
                            </div><!-- .product-meta -->
                        </li>
                        <?php endforeach; ?>

                    </ul><!-- .product-slider -->
                </div>
            </div><!-- #featured-products -->

       

    <?php }
endif;