<?php
/**
 * Blog section
 *
 * This is the template for the content of latest_post section
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */
if ( ! function_exists( 'medistore_pro_add_latest_post_section' ) ) :
    /**
    * Add latest_post section
    *
    *@since  Medistore Pro 1.0.0
    */
    function medistore_pro_add_latest_post_section() {
        $options = medistore_pro_get_theme_options();
        // Check if latest_post is enabled on frontpage
        $latest_post_enable = apply_filters( 'medistore_pro_section_status', true, 'latest_post_section_enable' );

        if ( true !== $latest_post_enable ) {
            return false;
        }
        // Get latest_post section details
        $section_details = array();
        $section_details = apply_filters( 'medistore_pro_filter_latest_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render latest_post section now.
        medistore_pro_render_latest_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'medistore_pro_get_latest_post_section_details' ) ) :
    /**
    * latest_post section details.
    *
    * @since  Medistore Pro 1.0.0
    * @param array $input latest_post section details.
    */
    function medistore_pro_get_latest_post_section_details( $input ) {
        $options = medistore_pro_get_theme_options();

        // Content type.
        $latest_post_content_type  = $options['latest_post_content_type'];
        $latest_post_count = ! empty( $options['latest_post_count'] ) ? $options['latest_post_count'] : 3;
        
        
        $content = array();
        switch ( $latest_post_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $latest_post_count; $i++ ) {
                    if ( ! empty( $options['latest_post_content_page_' . $i] ) )
                        $page_ids[] = $options['latest_post_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $latest_post_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $latest_post_count; $i++ ) {
                    if ( ! empty( $options['latest_post_content_post_' . $i] ) )
                        $post_ids[] = $options['latest_post_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $latest_post_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['latest_post_content_category'] ) ? $options['latest_post_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $latest_post_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['latest_post_category_exclude'] ) ? $options['latest_post_category_exclude'] : array();
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $latest_post_count ),
                    'category__not_in'      => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = medistore_pro_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// latest_post section content details.
add_filter( 'medistore_pro_filter_latest_post_section_details', 'medistore_pro_get_latest_post_section_details' );


if ( ! function_exists( 'medistore_pro_render_latest_post_section' ) ) :
  /**
   * Start latest_post section
   *
   * @return string latest_post content
   * @since  Medistore Pro 1.0.0
   *
   */
   function medistore_pro_render_latest_post_section( $content_details = array() ) {
        $options                = medistore_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="blog-latest-posts" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html( $options['latest_post_sub_title'] ); ?></p>
                        <h2 class="section-title"><?php echo esc_html( $options['latest_post_title'] ); ?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content <?php echo esc_attr( $options['latest_post_column'] ); ?> clear">
                    <?php foreach($content_details as $content) : ?>

                        <article>
                            <div class="blog-post-wrapper">
                            <span class="cat-links"><?php the_category(' ', '', $content['id'])?></span><!-- .cat-links -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']);?>" tabindex="0"><?php echo esc_html($content['title']) ?></a></h2>
                                </header>

                                <?php medistore_pro_posted_on($content['id']); ?>


                                <div class="featured-image">
                                    <a href="<?php echo esc_url($content['url']);?>"><img src="<?php echo esc_url($content['image']);?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                </div><!-- .entry-content -->


                                <?php if(!empty($options['latest_post_read_more_btn_label'])): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['latest_post_read_more_btn_label']); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div><!-- .blog-post-wrapper -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

    <?php }
endif;  ?>
