<?php
/**
 * Most Viewed section
 *
 * This is the template for the content of most_viewed section
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */
if ( ! function_exists( 'medistore_pro_add_most_viewed_section' ) ) :
    /**
    * Add most_viewed section
    *
    *@since  Medistore Pro 1.0.0
    */
    function medistore_pro_add_most_viewed_section() {
    	$options = medistore_pro_get_theme_options();
        // Check if most_viewed is enabled on frontpage
        $most_viewed_enable = apply_filters( 'medistore_pro_section_status', true, 'most_viewed_section_enable' );

        if ( true !== $most_viewed_enable ) {
            return false;
        }
        // Get most_viewed section details
        $section_details = array();
        $section_details = apply_filters( 'medistore_pro_filter_most_viewed_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render most_viewed section now.
        medistore_pro_render_most_viewed_section( $section_details );
}

endif;

if ( ! function_exists( 'medistore_pro_get_most_viewed_section_details' ) ) :
    /**
    * most_viewed section details.
    *
    * @since  Medistore Pro 1.0.0
    * @param array $input most_viewed section details.
    */
    function medistore_pro_get_most_viewed_section_details( $input ) {
        $options = medistore_pro_get_theme_options();

        // Content type.
        $most_viewed_content_type    = $options['most_viewed_content_type'];
        $most_viewed_count           = ! empty( $options['most_viewed_count'] ) ? $options['most_viewed_count'] : 2;
        
        $content = array();
        switch ( $most_viewed_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $most_viewed_count; $i++ ) {
                    if ( ! empty( $options['most_viewed_content_page_' . $i] ) )
                        $page_ids[] = $options['most_viewed_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $most_viewed_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $most_viewed_count; $i++ ) {
                    if ( ! empty( $options['most_viewed_content_post_' . $i] ) )
                        $post_ids[] = $options['most_viewed_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $most_viewed_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['most_viewed_category'] ) ? $options['most_viewed_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $most_viewed_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['excerpt']   = medistore_pro_trim_content(20);

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// most_viewed section content details.
add_filter( 'medistore_pro_filter_most_viewed_section_details', 'medistore_pro_get_most_viewed_section_details' );


if ( ! function_exists( 'medistore_pro_render_most_viewed_section' ) ) :
  /**
   * Start most_viewed section
   *
   * @return string most_viewed content
   * @since  Medistore Pro 1.0.0
   *
   */
   function medistore_pro_render_most_viewed_section( $content_details = array() ) {
        $options = medistore_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="magazine-most-viewed-posts" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-content col-2 clear">
                    <?php foreach ( $content_details as $content ) : ?>

                        <article class="has-post-thumbnail">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link" title="<?php echo esc_attr( $content['title'] ); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <?php the_category('', '',  $content['id']); ?>
                                

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>   

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post( $content['excerpt'] );?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>
    <?php
    }    
endif;

