<?php
/**
 * Services section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */
if ( ! function_exists( 'medistore_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since  Medistore Pro 1.0.0
    */
    function medistore_pro_add_service_section() {
    	$options = medistore_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'medistore_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'medistore_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        medistore_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'medistore_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since  Medistore Pro 1.0.0
    * @param array $input service section details.
    */
    function medistore_pro_get_service_section_details( $input ) {
        $options = medistore_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $service_posts_count = ! empty( $options['service_posts_count'] ) ? $options['service_posts_count'] : 3;
        
        $content = array();
        switch ( $service_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $service_posts_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $service_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $service_posts_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $service_posts_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_category'] ) ? $options['service_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $service_posts_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['content']   = medistore_pro_trim_content($options['service_excerpt_length']);
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'medistore_pro_filter_service_section_details', 'medistore_pro_get_service_section_details' );


if ( ! function_exists( 'medistore_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since  Medistore Pro 1.0.0
   *
   */
   function medistore_pro_render_service_section( $content_details = array() ) {
        $options    = medistore_pro_get_theme_options();
        $service_sub_title  = $options['service_section_sub_title'];
        $service_title      = isset($options['service_section_title']) ? $options['service_section_title']: '';
        $service_btn_url = (!empty($options['service_btn_url'])) ? $options['service_btn_url'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="our-services" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html($service_sub_title); ?></p>
                        <h2 class="section-title"><?php echo esc_html($service_title); ?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content" data-slick='{"slidesToShow": 3, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
                    <?php foreach ( $content_details as $i=>$content ) : ?>
                        
                    <article>
                            <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['content']); ?></p>
                                </div><!-- .entry-content -->

                                <?php if(!empty($options['service_post_btn_title'])) : ?>
                                <div class="more-link">
                                    <a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($options['service_post_btn_title']); ?></a>
                                    <svg viewBox="0 0 292.359 292.359">
                                        <path d="M222.979,133.331L95.073,5.424C91.456,1.807,87.178,0,82.226,0c-4.952,0-9.233,1.807-12.85,5.424
                                        c-3.617,3.617-5.424,7.898-5.424,12.847v255.813c0,4.948,1.807,9.232,5.424,12.847c3.621,3.617,7.902,5.428,12.85,5.428
                                        c4.949,0,9.23-1.811,12.847-5.428l127.906-127.907c3.614-3.613,5.428-7.897,5.428-12.847
                                        C228.407,141.229,226.594,136.948,222.979,133.331z"/>
                                    </svg>
                                </div><!-- .more-link -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .section-content -->

                    <?php if(!empty($options['service_btn_title']) && !empty($service_btn_url)) : ?>
                        <div class="read-more">
                            <a href="<?php echo esc_url($service_btn_url); ?>" class="btn"><?php echo esc_html( $options['service_btn_title'] ); ?></a>
                        </div><!-- .read-more -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #our-services --> 

    <?php
    }    
endif; ?>
