<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Medistore Pro
 * @since Medistore Pro 1.0.0
 */
if ( ! function_exists( 'medistore_pro_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Medistore Pro 1.0.0
    */
    function medistore_pro_add_subscription_section() {
        $options = medistore_pro_get_theme_options();
        if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        }

        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'medistore_pro_section_status', true, 'subscription_section_enable' );

        if ( true !== $subscription_enable ) {
            return false;
        }
        // Render subscription section now.
        medistore_pro_render_subscription_section();
    }
endif;

if ( ! function_exists( 'medistore_pro_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Medistore Pro 1.0.0
   *
   */
   function medistore_pro_render_subscription_section() {
        $options = medistore_pro_get_theme_options(); 
        $subscription_bg_image = !empty($options['subscription_bg_image']) ? $options['subscription_bg_image'] : ''; ?>

    
        <div id="subscribe-now" class="relative page-section" style="background-image: url('<?php echo esc_url($subscription_bg_image); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['subscription_section_title'] ); ?></h2>
                </div><!-- .section-header -->

                <div class="subscribe-form-wrapper">
                <?php 
                    $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html( $options['subscription_section_btn_txt'] ) . '" show_subscribers_total="0"]';
                    echo do_shortcode( wp_kses_post( $subscription_shortcode ) );  ?>
                </div><!-- .subscribe-form-wrapper -->
            </div><!-- .wrapper -->
        </div>
        
    <?php
    }
endif; ?>
