<?php
/**
 * Testimonial section
 *
 * This is the template for the content of Testimonial section
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */

if ( ! function_exists( 'medistore_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since  Medistore Pro 1.0.0
    */
    function medistore_pro_add_testimonial_section() {
    	$options = medistore_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'medistore_pro_section_status', true, 'testimonial_section_enable' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'medistore_pro_filter_testimonial_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render testimonial section now.
        medistore_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'medistore_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since  Medistore Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function medistore_pro_get_testimonial_section_details( $input ) {
        $options = medistore_pro_get_theme_options();

        // Content type.
        $testimonial_content_type   = $options['testimonial_content_type'];
        $testimonial_count          = isset($options['testimonial_posts_count'] ) ? $options['testimonial_posts_count'] : 3;

        $content = array();
        switch ( $testimonial_content_type ) {
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) )
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) )
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                }

                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $testimonial_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_category'] ) ? $options['testimonial_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $testimonial_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );
            break;

            default:
            break;
        }
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) :
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['content']        = medistore_pro_trim_content($options['testimonial_excerpt_length']);
                $page_post['title']          = get_the_title();
                $page_post['url']            = get_the_permalink();
                $page_post['image']          = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['designation']    = isset($options['testimonial_post_designation_'.$i])?$options['testimonial_post_designation_'.$i] : '';
                // Push to the main array.
                array_push( $content, $page_post );
                $i++;
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'medistore_pro_filter_testimonial_section_details', 'medistore_pro_get_testimonial_section_details' );


if ( ! function_exists( 'medistore_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since  Medistore Pro 1.0.0
   *
   */
   function medistore_pro_render_testimonial_section( $content_details = array() ) {
    $options            = medistore_pro_get_theme_options();

    if ( empty( $content_details ) ) {
        return;
    } ?>
            
        <div id="testimonials" class="relative page-section">
            <div class="wrapper">
                <div class="testimonial-slider">
                    <div class="slider-nav">
                        <?php foreach($content_details as $content): ?>

                            <article>
                                <div class="entry-container">
                                    <div class="featured-image">
                                        <img src="<?php echo esc_url($content['image']); ?>" alt="<?php echo esc_attr($content['title']); ?>">
                                    </div><!-- .featured-image -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                        <span class="testimonial-position"><?php echo esc_html($content['designation']); ?></span>
                                    </header>
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach; ?>
                    
                    </div>

                    <div class="slider-for">
                        <?php foreach($content_details as $content): ?>

                        <article>
                            <div class="section-header">
                                <p class="section-subtitle"><?php echo esc_html( $options['testimonial_title'] ); ?></p>
                            </div>
                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['content']); ?></p>
                            </div><!-- .entry-content -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .slider-for-->
                    
                </div>
            </div>
        </div><!-- #testimonials-->
     
    <?php
    }
endif; ?>
