<?php
/**
 * Stories section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage  Medistore Pro
 * @since  Medistore Pro 1.0.0
 */
if ( ! function_exists( 'medistore_pro_add_three_column_section' ) ) :
    /**
    * Add Stories section
    *
    *@since  Medistore Pro 1.0.0
    */
    function medistore_pro_add_three_column_section() {
        $options = medistore_pro_get_theme_options();
        // Check if Stories is enabled on frontpage
        $three_column_enable = apply_filters( 'medistore_pro_section_status', true, 'three_column_section_enable' );

        if ( true !== $three_column_enable ) {
            return false;
        }
        // Get Stories section details
        $section_details = array();
        $section_details = apply_filters( 'medistore_pro_filter_three_column_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render Stories section now.
        medistore_pro_render_three_column_section( $section_details );
    }
endif;

if ( ! function_exists( 'medistore_pro_get_three_column_section_details' ) ) :
    /**
    * Stories section details.
    *
    * @since  Medistore Pro 1.0.0
    * @param array $input Stories section details.
    */
    function medistore_pro_get_three_column_section_details( $input ) {
        $options = medistore_pro_get_theme_options();

        // Content type.
        $three_column_content_type  = $options['three_column_content_type'];
        $three_column_count = ! empty( $options['three_column_count'] ) ? $options['three_column_count'] : 3;
        
        
        $content = array();
        switch ( $three_column_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $three_column_count; $i++ ) {
                    if ( ! empty( $options['three_column_content_page_' . $i] ) )
                        $page_ids[] = $options['three_column_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $three_column_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $three_column_count; $i++ ) {
                    if ( ! empty( $options['three_column_content_post_' . $i] ) )
                        $post_ids[] = $options['three_column_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $three_column_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['three_column_content_category'] ) ? $options['three_column_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $three_column_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['three_column_category_exclude'] ) ? $options['three_column_category_exclude'] : array();
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $three_column_count ),
                    'category__not_in'      => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = medistore_pro_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'medistore_pro_filter_three_column_section_details', 'medistore_pro_get_three_column_section_details' );


if ( ! function_exists( 'medistore_pro_render_three_column_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since  Stories Press Pro 1.0.0
   *
   */
   function medistore_pro_render_three_column_section( $content_details = array() ) {
        $options                = medistore_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

            <div id="magazine-three-column-posts" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html($options['three_column_title']); ?></h2>
                    </div><!-- .section-header -->

                    <div class="col-3 clear">
                    <?php foreach($content_details as $content) : ?>

                        <article>
                            <div class="featured-post-item">
                                <div class="featured-image">
                                <img src="<?php echo esc_url($content['image']);?>" alt="<?php echo esc_attr($content['title']); ?>">

                                <?php medistore_pro_posted_on($content['id']); ?>

                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                <?php echo the_category('', '', $content['id'])?>


                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>   

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .featured-post-item -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div>

<?php }
endif;  ?>